==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/pt_PT.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Atividades",
    "An error occurred while loading activities" : "Ocorreu um erro durante o carregamento das actividades",
    "No activity yet" : "Ainda sem atividade",
    "Load more activities" : "Adicionar mais atividades ",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
    "{name} (invisible)" : "{name} (invisível)",
    "{name} (restricted)" : "{name} (limitado)",
    "in {path}" : "em {path}",
    "This stream will show events like additions, changes & shares" : "Esta transmissão irá mostrar os eventos como adições, alterações e partilhas",
    "There are no events for this filter" : "Não existem eventos para este filtro",
    "Today" : "Hoje",
    "Yesterday" : "Ontem",
    "Open file" : "Abrir ficheiro",
    "Personal activity feed for %s" : "Actividade pessoal de feed para %s",
    "Your feed URL is invalid" : "O URL do feed é inválido.",
    "Your settings have been updated." : "As suas definições foram actualizadas.",
    "Settings have been updated." : "Definições foram actualizadas",
    "Mail" : "Correio",
    "Stream" : "Transmissão",
    "All activities" : "Todas as atividades",
    "By others" : "Por outros",
    "By you" : "Por si",
    "\"remote user\"" : "\"utilizador remoto\"",
    "Hello %s" : "Olá %s",
    "Hello %s," : "Olá %s,",
    "There was some activity at %s" : "Houve alguma atividade em %s",
    "Activity notification" : "Notificação de Atividade",
    ", " : ", ",
    "%s and %s" : "%s e %s",
    "Activity" : "Atividade",
    "Activity feed" : "Actividade de feed",
    "Send activity emails" : "Enviar actividade de emails",
    "Default settings" : "Definições padrão",
    "Configure the default activity settings for new users." : "Configurar definições padrão das actividades para novos utilizadores",
    "List your own actions in the stream" : "Liste as suas próprias acções na transmissão",
    "Notify about your own actions via email" : "Notificar sobre as suas próprias acções via correio electrónico ",
    "You need to set up your email address before you can receive notification emails." : "Precisa de configurar o seu endereço de correio electrónico antes de poder receber notificações na sua caixa de correio.",
    "Send emails:" : "Enviar emails:",
    "As soon as possible" : "Logo que possível",
    "Hourly" : "Hora a hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Escolher as actividades que pretende serem notificiações por email e quais irão ser mostradas nas actividades app stream.",
    "Choose which activities you want to see in your stream." : "Escolha quais as atividades que quer ver no seu stream.",
    "Settings" : "Definições",
    "Enable RSS feed" : "Activar feed RSS",
    "RSS feed" : "RSS feed",
    "No more events to load" : "Sem mais eventos para carregar",
    "Files" : "Ficheiros",
    "Error loading activities" : "Erro ao carregar atividades",
    "No activities" : "Sem actividades",
    "You are receiving this email because the following things happened at %s" : "Recebeste este email devido às seguintes causas %s",
    "* %1$s - %2$s" : "* %1$s - %2$s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/pt_PT.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Atividades",
    "An error occurred while loading activities" : "Ocorreu um erro durante o carregamento das actividades",
    "No activity yet" : "Ainda sem atividade",
    "Load more activities" : "Adicionar mais atividades ",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
    "{name} (invisible)" : "{name} (invisível)",
    "{name} (restricted)" : "{name} (limitado)",
    "in {path}" : "em {path}",
    "This stream will show events like additions, changes & shares" : "Esta transmissão irá mostrar os eventos como adições, alterações e partilhas",
    "There are no events for this filter" : "Não existem eventos para este filtro",
    "Today" : "Hoje",
    "Yesterday" : "Ontem",
    "Open file" : "Abrir ficheiro",
    "Personal activity feed for %s" : "Actividade pessoal de feed para %s",
    "Your feed URL is invalid" : "O endereço do feed é inválido.",
    "Your settings have been updated." : "As suas definições foram actualizadas.",
    "Settings have been updated." : "Definições foram actualizadas",
    "Mail" : "Correio",
    "Stream" : "Transmissão",
    "All activities" : "Todas as atividades",
    "By others" : "Por outros",
    "By you" : "Por si",
    "\"remote user\"" : "\"utilizador remoto\"",
    "Hello %s" : "Olá %s",
    "Hello %s," : "Olá %s,",
    "There was some activity at %s" : "Houve alguma atividade em %s",
    "Activity notification" : "Notificação de Atividade",
    ", " : ", ",
    "%s and %s" : "%s e %s",
    "Activity" : "Atividade",
    "Activity feed" : "Actividade de feed",
    "Send activity emails" : "Enviar actividade de emails",
    "Default settings" : "Definições padrão",
    "Configure the default activity settings for new users." : "Configurar definições padrão das actividades para novos utilizadores",
    "List your own actions in the stream" : "Liste as suas próprias acções na transmissão",
    "Notify about your own actions via email" : "Notificar sobre as suas próprias acções via correio electrónico ",
    "You need to set up your email address before you can receive notification emails." : "Precisa de configurar o seu endereço de correio electrónico antes de poder receber notificações na sua caixa de correio.",
    "Send emails:" : "Enviar emails:",
    "As soon as possible" : "Logo que possível",
    "Hourly" : "Hora a hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Escolher as actividades que pretende serem notificiações por email e quais irão ser mostradas nas actividades app stream.",
    "Choose which activities you want to see in your stream." : "Escolha quais as atividades que quer ver no seu stream.",
    "Settings" : "Definições",
    "Enable RSS feed" : "Activar feed RSS",
    "RSS feed" : "RSS feed",
    "No more events to load" : "Sem mais eventos para carregar",
    "Files" : "Ficheiros",
    "Error loading activities" : "Erro ao carregar atividades",
    "No activities" : "Sem actividades",
    "You are receiving this email because the following things happened at %s" : "Recebeste este email devido às seguintes causas %s",
    "* %1$s - %2$s" : "* %1$s - %2$s"
},
"nplurals=2; plural=(n != 1);");
